//
//  UUIDTest.cpp
//
//  Created  by Setsu on 5/30/2010.
//  Modified by Setsu on May 30, 2013.
//  Copyright 2010-2013 RoundSquare Inc. All rights reserved.
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
// 
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

//----------------------------------------
//	include
//----------------------------------------
#include <Poco/Format.h>
#include <Poco/UUID.h>
#include <Poco/UUIDGenerator.h>
#ifndef POCO_VERSION
#include <Poco/Version.h>
#endif

#include <string>

#include "ScopedLogMessage.h"
#include "PrepareConsoleLogger.h"

//----------------------------------------
//	ShowUUID
//----------------------------------------
void ShowUUID(ScopedLogMessage& msg, const Poco::UUID& uuid, const std::string& text)
{
	msg.Message(Poco::format("%s %s [version=%d]"
				, text
				, uuid.toString()
				, static_cast<int>(uuid.version())));
}

//----------------------------------------
//	main
//----------------------------------------
int main(int /*argc*/, char** /*argv*/)
{
	PrepareConsoleLogger logger(Poco::Logger::ROOT, Poco::Message::PRIO_INFORMATION);

	ScopedLogMessage msg("UUIDTest ", "start", "end");

	msg.Message("--- Poco::UUID static methods ---");
	ShowUUID(msg, Poco::UUID::dns(),  "  dns()  :");
#if (POCO_VERSION < 0x01040000)
	ShowUUID(msg, Poco::UUID::nil(),  "  nil()  :");
#else
	ShowUUID(msg, Poco::UUID::null(), "  null() :");
#endif
	ShowUUID(msg, Poco::UUID::oid(),  "  oid()  :");
	ShowUUID(msg, Poco::UUID::uri(),  "  uri()  :");
	ShowUUID(msg, Poco::UUID::x500(), "  x500() :");

	const int kNumGeneratorLoop = 2;
	const std::string kCreateFromName("test");

	for(int i=0; i<kNumGeneratorLoop; ++i)
	{
		msg.Message(Poco::format("--- Poco::UUIDGenerator (%d of %d) ---", i+1, kNumGeneratorLoop));
		Poco::UUID uuid;
		try
		{
			uuid = Poco::UUIDGenerator::defaultGenerator().create();
			ShowUUID(msg, uuid, "  create()       :");
		}
		catch(Poco::Exception& exc)
		{
			msg.Message(Poco::format("  create() throwed exception: %s", exc.displayText()));
		}
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createOne(), "  createOne()    :");
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createRandom(), "  createRandom() :");
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createFromName(Poco::UUID::dns(), kCreateFromName)
				, "  createFromName(dns(),  \""+kCreateFromName+"\") :");
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createFromName(Poco::UUID::oid(), kCreateFromName)
				, "  createFromName(oid(),  \""+kCreateFromName+"\") :");
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createFromName(Poco::UUID::uri(), kCreateFromName)
				, "  createFromName(uri(),  \""+kCreateFromName+"\") :");
		ShowUUID(msg, Poco::UUIDGenerator::defaultGenerator().createFromName(Poco::UUID::x500(), kCreateFromName)
				, "  createFromName(x500(), \""+kCreateFromName+"\") :");
	}

	return 0;
}
